==> haskell-microlens-platform-0.3.9.0-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.3.9.0
id: microlens-platform-0.3.9.0-Iev8NyylQRxKCvWTUQocIw
key: microlens-platform-0.3.9.0-Iev8NyylQRxKCvWTUQocIw
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: Feature-complete microlens
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
indefinite: False
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
abi: 5b8d5ff6c007fe497d69bdaea490bec0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-platform-0.3.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-platform-0.3.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/microlens-platform-0.3.9.0
hs-libraries: HSmicrolens-platform-0.3.9.0-Iev8NyylQRxKCvWTUQocIw
depends:
    base-4.10.1.0 hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk
    microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote
    microlens-ghc-0.4.8.0-LgyzN1fsM1jJTR3dDQxT6S
    microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml
    microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk=526c49aca960d0292e5723576545a03d
             microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote=d342bc9a9b35c935919ac21479dbef0f
             microlens-ghc-0.4.8.0-LgyzN1fsM1jJTR3dDQxT6S=f629602bcbef372eb7264b8685d7054a
             microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml=3622355c9ffb7a425ad3cab2b75d0a6c
             microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q=0a9da82dd00392e1b1481699ba3b8067
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.3.9.0-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.3.9.0
id: microlens-platform-0.3.9.0-2KXp6Fd6qSgDZyE7NlOBRo
key: microlens-platform-0.3.9.0-2KXp6Fd6qSgDZyE7NlOBRo
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: Feature-complete microlens
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
indefinite: False
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
abi: 2bc16d42c059bacd542bd9c7af892005
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-platform-0.3.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-platform-0.3.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/microlens-platform-0.3.9.0
hs-libraries: HSmicrolens-platform-0.3.9.0-2KXp6Fd6qSgDZyE7NlOBRo
depends:
    base-4.10.1.0 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote
    microlens-ghc-0.4.8.0-LgyzN1fsM1jJTR3dDQxT6S
    microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml
    microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote=d342bc9a9b35c935919ac21479dbef0f
             microlens-ghc-0.4.8.0-LgyzN1fsM1jJTR3dDQxT6S=f629602bcbef372eb7264b8685d7054a
             microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml=3622355c9ffb7a425ad3cab2b75d0a6c
             microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q=0a9da82dd00392e1b1481699ba3b8067
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
